@@ -49,6 +49,7 @@
 #include <kscreensaver.h>
 
 #include "kpartsaver.h"
+#include <kaboutapplicationdialog.h>
 #include <kiconloader.h>
 #include <kglobal.h>
 
@@ -56,14 +57,14 @@
 QList<KPartSaver*> g_savers;
 bool g_inited = false;
 
-
+static KAboutData* s_aboutData = 0;
 class KPartSaverInterface : public KScreenSaverInterface
 {
 
 
 public:
     virtual KAboutData* aboutData() {
-        return new KAboutData( "kpartsaver", 0, ki18n( "KPart Screen Saver" ), "1.0", ki18n( "KPart Screen Saver" ) );
+        return s_aboutData;
     }
 
 
@@ -82,6 +83,8 @@ public:
 
 int main( int argc, char *argv[] )
 {
+    s_aboutData = new KAboutData( "kpartsaver", 0, ki18n( "KPart Screen Saver" ), "1.0", ki18n( "KPart Screen Saver" ) );
+
     KPartSaverInterface kss;
     return kScreenSaverMain( argc, argv, kss );
 }
@@ -264,38 +267,46 @@ void KPartSaver::next( bool random )
 
 
 SaverConfig::SaverConfig( QWidget* parent )
-    : ConfigWidget( parent )
+    : KDialog( parent )
 {
+    setCaption(i18n( "Media Screen Saver" ));
+    setButtons(Ok|Cancel|Help);
+    setDefaultButton(Ok);
     setModal(true);
-    connect( m_ok, SIGNAL(clicked()), SLOT(apply()) );
-    connect( m_ok, SIGNAL(clicked()), SLOT(accept()) );
-    connect( m_cancel, SIGNAL(clicked()), SLOT(reject()) );
+    setButtonText( Help, i18n( "A&bout" ) );
+    QWidget *main = new QWidget(this);
+    setMainWidget(main);
+    cfg = new ConfigWidget();
+    cfg->setupUi( main );
 
-    connect( m_multiple, SIGNAL(toggled(bool)), m_delayLabel, SLOT(setEnabled(bool)) );
-    connect( m_multiple, SIGNAL(toggled(bool)), m_delay, SLOT(setEnabled(bool)) );
-    connect( m_multiple, SIGNAL(toggled(bool)), m_secondsLabel, SLOT(setEnabled(bool)) );
-    connect( m_multiple, SIGNAL(toggled(bool)), m_random, SLOT(setEnabled(bool)) );
+    connect(this,SIGNAL(okClicked()),this,SLOT(apply()));
+    connect(this,SIGNAL(helpClicked()),this,SLOT(slotHelp()));
 
-    connect( m_files, SIGNAL(itemSelectionChanged()), SLOT(select()) );
-    connect( m_add, SIGNAL(clicked()), SLOT(add()) );
-    connect( m_remove, SIGNAL(clicked()), SLOT(remove()) );
-    connect( m_up, SIGNAL(clicked()), SLOT(up()) );
-    connect( m_down, SIGNAL(clicked()), SLOT(down()) );
+    connect( cfg->m_multiple, SIGNAL(toggled(bool)), cfg->m_delayLabel, SLOT(setEnabled(bool)) );
+    connect( cfg->m_multiple, SIGNAL(toggled(bool)), cfg->m_delay, SLOT(setEnabled(bool)) );
+    connect( cfg->m_multiple, SIGNAL(toggled(bool)), cfg->m_secondsLabel, SLOT(setEnabled(bool)) );
+    connect( cfg->m_multiple, SIGNAL(toggled(bool)), cfg->m_random, SLOT(setEnabled(bool)) );
 
-    m_up->setIcon( KIcon("go-up") );
-    m_down->setIcon( KIcon("go-down") );
+    connect( cfg->m_files, SIGNAL(itemSelectionChanged()), SLOT(select()) );
+    connect( cfg->m_add, SIGNAL(clicked()), SLOT(add()) );
+    connect( cfg->m_remove, SIGNAL(clicked()), SLOT(remove()) );
+    connect( cfg->m_up, SIGNAL(clicked()), SLOT(up()) );
+    connect( cfg->m_down, SIGNAL(clicked()), SLOT(down()) );
+
+    cfg->m_up->setIcon( KIcon("go-up") );
+    cfg->m_down->setIcon( KIcon("go-down") );
 
     // load config
-    KConfigGroup cfg(KGlobal::config(), "Misc");
+    KConfigGroup grp(KGlobal::config(), "Misc");
 
-    bool single = cfg.readEntry( "Single", true );
-    m_single->setChecked( single );
-    m_multiple->setChecked( !single );
-    m_delay->setMinimum( 1 );
-    m_delay->setMaximum( 10000 );
-    m_delay->setValue( cfg.readEntry( "Delay", 60 ) );
-    m_random->setChecked( cfg.readEntry( "Random", false ) );
-    m_files->addItems( cfg.readEntry( "Files",QStringList() ) );
+    bool single = grp.readEntry( "Single", true );
+    cfg->m_single->setChecked( single );
+    cfg->m_multiple->setChecked( !single );
+    cfg->m_delay->setMinimum( 1 );
+    cfg->m_delay->setMaximum( 10000 );
+    cfg->m_delay->setValue( grp.readEntry( "Delay", 60 ) );
+    cfg->m_random->setChecked( grp.readEntry( "Random", false ) );
+    cfg->m_files->addItems( grp.readEntry( "Files",QStringList() ) );
 
     // update buttons
     select();
@@ -304,6 +315,7 @@ SaverConfig::SaverConfig( QWidget* parent )
 
 SaverConfig::~SaverConfig()
 {
+    delete cfg;
 }
 
 
@@ -311,70 +323,77 @@ void SaverConfig::apply()
 {
     kDebug() << "apply";
 
-    KConfigGroup cfg(KGlobal::config(), "Misc");
+    KConfigGroup grp(KGlobal::config(), "Misc");
 
-    cfg.writeEntry( "Single", m_single->isChecked() );
-    cfg.writeEntry( "Delay", m_delay->value() );
-    cfg.writeEntry( "Random", m_random->isChecked() );
+    grp.writeEntry( "Single", cfg->m_single->isChecked() );
+    grp.writeEntry( "Delay", cfg->m_delay->value() );
+    grp.writeEntry( "Random", cfg->m_random->isChecked() );
 
-    int num = m_files->count();
+    int num = cfg->m_files->count();
     QStringList files;
     for( int n=0; n<num; n++ )
-        files << m_files->item(n)->text();
+        files << cfg->m_files->item(n)->text();
 
-    cfg.writeEntry( "Files", files );
+    grp.writeEntry( "Files", files );
 
-    cfg.sync();
+    grp.sync();
+    accept();
 }
 
 
 void SaverConfig::add()
 {
-    KUrl::List files = KFileDialog::getOpenUrls( KUrl(), QString(),
+    const KUrl::List files = KFileDialog::getOpenUrls( KUrl(), QString(),
                                                  this, i18n("Select Media Files") );
     for( int n=0; n<files.count(); n++ )
-        m_files->addItem( files[n].prettyUrl() );
+        cfg->m_files->addItem( files[n].prettyUrl() );
 }
 
 
 void SaverConfig::remove()
 {
-    int current = m_files->currentRow();
+    int current = cfg->m_files->currentRow();
     if( current!=-1 )
-        m_files->takeItem( current );
+        cfg->m_files->takeItem( current );
 }
 
 
 void SaverConfig::select()
 {
-    bool enabled = m_files->currentRow()!=-1;
-    m_remove->setEnabled( enabled );
-    m_up->setEnabled( enabled && m_files->currentRow()!=0 );
-    m_down->setEnabled( enabled && m_files->currentRow()!=(int)m_files->count()-1 );
+    bool enabled = cfg->m_files->currentRow()!=-1;
+    cfg->m_remove->setEnabled( enabled );
+    cfg->m_up->setEnabled( enabled && cfg->m_files->currentRow()!=0 );
+    cfg->m_down->setEnabled( enabled && cfg->m_files->currentRow()!=(int)cfg->m_files->count()-1 );
 }
 
 
 void SaverConfig::up()
 {
-    int current = m_files->currentRow();
+    const int current = cfg->m_files->currentRow();
     if ( current>0 ) {
-        QString txt = m_files->currentItem()->text();
-        m_files->takeItem( current );
-        m_files->insertItem( current-1, txt );
-        m_files->setCurrentRow( current-1 );
+        QString txt = cfg->m_files->currentItem()->text();
+        cfg->m_files->takeItem( current );
+        cfg->m_files->insertItem( current-1, txt );
+        cfg->m_files->setCurrentRow( current-1 );
     }
 }
 
 
 void SaverConfig::down()
 {
-    int current = m_files->currentRow();
-    if ( current!=-1 && current<(int)m_files->count()-1 ) {
-        QString txt = m_files->currentItem()->text();
-        m_files->takeItem( current );
-        m_files->insertItem( current+1, txt );
-        m_files->setCurrentRow( current+1 );
+    const int current = cfg->m_files->currentRow();
+    if ( current!=-1 && current<(int)cfg->m_files->count()-1 ) {
+        QString txt = cfg->m_files->currentItem()->text();
+        cfg->m_files->takeItem( current );
+        cfg->m_files->insertItem( current+1, txt );
+        cfg->m_files->setCurrentRow( current+1 );
     }
 }
 
+void SaverConfig::slotHelp()
+{
+    KAboutApplicationDialog mAbout(s_aboutData, this);
+    mAbout.exec();
+}
+
 #include "kpartsaver.moc"
